==> rwa_camera-0.0.27.tar.gz: lib/CameraModule/editPreview.dart <==
import 'dart:io';
import 'dart:math' as math;
import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:image_editor/image_editor.dart';
class EditPreview extends StatefulWidget {
  XFile xImageFile;
   EditPreview(this.xImageFile, {Key? key}) : super(key: key);

  @override
  _EditPreviewState createState() => _EditPreviewState();
}

class _EditPreviewState extends State<EditPreview> {
  late double fullWidth;
  late double fullHeight;
  late XFile xImageFile;
  bool isRotated = false;
  @override
  void initState() {
    // TODO: implement initState
    xImageFile = widget.xImageFile;
    super.initState();

  }
  @override
  Widget build(BuildContext context) {
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
    ]);
    fullWidth = MediaQuery.of(context).size.width;
    fullHeight = MediaQuery.of(context).size.height;

    return Scaffold(body: Stack(
      children: [
        Transform.rotate(angle:isRotated?math.pi:0,child: Container(alignment:Alignment.center,child: Image.file(File(xImageFile.path),))),
        Column(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Container(
              width: fullWidth,
              height: (fullHeight-fullWidth*4/3)/2,
              color: Colors.black,
            ),

            Container(
              width: fullWidth,
              height: (fullHeight-fullWidth*4/3)/2,
              color: Colors.black,
            )
          ],
        ),
        Positioned(
          bottom: 0,
          child: Container(
            height: 100,
            width: MediaQuery.of(context).size.width,
            //color: Color.fromRGBO(0, 0, 0, .5),
            child: Builder(builder: (context){
              return Row(
                mainAxisAlignment: MainAxisAlignment.spaceAround,
                children: [
                  Expanded(flex: 1,child: cancelIt()),
                  Expanded(flex: 1,child: okayIt()),
                  Expanded(flex: 1,child: rotate()),

                ],
              );
            } ,
            ),
          ),
        ),
      ],
    ),);
  }

  Widget cancelIt(){
    return GestureDetector(
        onTap: (){
          Navigator.pop(context,[false]);
        },
        child: Container(decoration: BoxDecoration(shape: BoxShape.circle,color: Colors.white12,),width:50,height: 50,alignment:Alignment.center,child: Image.asset('assets/cancel@3x.png',package: 'rwa_camera',width: 20,height: 20,)));
  }

  Widget okayIt(){
    return GestureDetector(
        onTap: ()async{
           if(isRotated) {
             final snackBar = SnackBar(content: Text('Rotating'));
             ScaffoldMessenger.of(context).showSnackBar(snackBar);
            final editorOption = ImageEditorOption();
            editorOption.addOption(RotateOption(180));
            editorOption.outputFormat = OutputFormat.png(100);
            File? editFileImageAndGetFile = await ImageEditor.editFileImageAndGetFile(file: File(xImageFile.path), imageEditorOption: editorOption);

            Navigator.pop(context,[true,XFile(editFileImageAndGetFile!.path)]);

          }else{
             Navigator.pop(context,[true,xImageFile]);

           }
        },
        child: Image.asset('assets/camera.png',package: 'rwa_camera',));
  }

  Widget rotate(){
    return GestureDetector(
        onTap: (){
          isRotated = !isRotated;
          setState(() {

          });
        },
        child: Container(decoration: BoxDecoration(shape: BoxShape.circle,color: Colors.white12,),width:50,height: 50,alignment:Alignment.center,child: Image.asset('assets/rotation-1@3x.png',package: 'rwa_camera',width: 20,height: 20,)));
  }

}

==> rwa_camera-0.0.30.tar.gz: lib/CameraModule/editPreview.dart <==
import 'dart:io';
import 'dart:math' as math;
import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:image_editor/image_editor.dart';
class EditPreview extends StatefulWidget {
  XFile xImageFile;
   EditPreview(this.xImageFile, {Key? key}) : super(key: key);

  @override
  _EditPreviewState createState() => _EditPreviewState();
}

class _EditPreviewState extends State<EditPreview> {
  late double fullWidth;
  late double fullHeight;
  late XFile xImageFile;
  bool isRotated = false;
  @override
  void initState() {
    // TODO: implement initState
    xImageFile = widget.xImageFile;
    super.initState();

  }
  @override
  Widget build(BuildContext context) {
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
    ]);
    fullWidth = MediaQuery.of(context).size.width;
    fullHeight = MediaQuery.of(context).size.height;

    return Scaffold(body: Stack(
      children: [
        Transform.rotate(angle:isRotated?math.pi:0,child: Container(alignment:Alignment.center,child: Image.file(File(xImageFile.path),))),
        Column(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Container(
              width: fullWidth,
              height: (fullHeight-fullWidth*4/3)/2,
              color: Colors.black,
            ),

            Container(
              width: fullWidth,
              height: (fullHeight-fullWidth*4/3)/2,
              color: Colors.black,
            )
          ],
        ),
        Positioned(
          bottom: 0,
          child: Container(
            height: 100,
            width: MediaQuery.of(context).size.width,
            //color: Color.fromRGBO(0, 0, 0, .5),
            child: Builder(builder: (context){
              return Row(
                mainAxisAlignment: MainAxisAlignment.spaceAround,
                children: [
                  Expanded(flex: 1,child: cancelIt()),
                  Expanded(flex: 1,child: okayIt()),
                  Expanded(flex: 1,child: rotate()),

                ],
              );
            } ,
            ),
          ),
        ),
      ],
    ),);
  }

  Widget cancelIt(){
    return GestureDetector(
        onTap: (){
          Navigator.pop(context,[false]);
        },
        child: Container(decoration: BoxDecoration(shape: BoxShape.circle,color: Colors.white12,),width:50,height: 50,alignment:Alignment.center,child: Image.asset('assets/cancel@3x.png',package: 'rwa_camera',width: 20,height: 20,)));
  }

  Widget okayIt(){
    return GestureDetector(
        onTap: ()async{
           if(isRotated) {
             final snackBar = SnackBar(content: Text('Saving'));
             ScaffoldMessenger.of(context).showSnackBar(snackBar);
            final editorOption = ImageEditorOption();
            editorOption.addOption(RotateOption(180));
            editorOption.outputFormat = OutputFormat.png(100);
            File? editFileImageAndGetFile = await ImageEditor.editFileImageAndGetFile(file: File(xImageFile.path), imageEditorOption: editorOption);

            Navigator.pop(context,[true,XFile(editFileImageAndGetFile!.path)]);

          }else{
             Navigator.pop(context,[true,xImageFile]);

           }
        },
        child: Image.asset('assets/camera.png',package: 'rwa_camera',));
  }

  Widget rotate(){
    return GestureDetector(
        onTap: (){
          isRotated = !isRotated;
          setState(() {

          });
        },
        child: Container(decoration: BoxDecoration(shape: BoxShape.circle,color: Colors.white12,),width:50,height: 50,alignment:Alignment.center,child: Image.asset('assets/rotation-1@3x.png',package: 'rwa_camera',width: 20,height: 20,)));
  }

}
